# NCBI Pubmed Toolkits

## Requirements
- Python3.6+

## Installation
```bash
pip3 isntall pypubmed
```

## Usage
### `search`
> search Pubmed with term
```bash
pypubmed search --help
```

### `advance-search`
> advance search builder
```bash
pypubmed advance-search --help
```
![](https://suqingdong.github.io/pypubmed/src/advance-search.png)

### `citations`
> generate citations for given PMID
```bash
pypubmed citations --help
```

## Todos
- [ ] HTML output
- [ ] PDF downloader
- [ ] GUI application
- [ ] Local paper manager


## Documents
> https://pypubmed.readthedocs.io/en/latest/
